import React, { useRef, useEffect, useCallback } from "react";
import styled from "styled-components";
import usePano from "./usePano";

const Container = styled.div`
  position: relative;
  height: 100%;
  width: 100%;
`

const Pano = styled.div`
  height: 100%;
  width: 100%;
`

const ResetButton = styled.div`
  /* TODO improve this to be less brittle */
  display: block;
  position: absolute;
  z-index: 1;
  bottom: 200px;
  right: 9px;
  background-color: #222;
  color: #666;
  padding: 5px;
  border-radius: 2px;
  font-weight: bold;
  cursor: pointer;

  &:hover {
    color: #b1b1b1;
  }
`

export default ({ startPosition, resetPosition, onPanoMoved }) => {
  const panoDivRef = useRef(null);
  const panoRef = usePano(panoDivRef, { lat: 0, lng: 0 });
  useEffect(() => {
    if (panoRef.current) {
      panoRef.current.setPosition(startPosition);
    }
  }, [panoRef, startPosition]);
  const panoChangeCallback = useCallback(() => {
    const pos = panoRef.current.getPosition();
    const pov = panoRef.current.getPov();
    onPanoMoved(pos.lat(), pos.lng(), pov.heading, pov.pitch);
  }, [panoRef, onPanoMoved]);
  useEffect(() => {
    if (panoRef.current) {
      panoRef.current.addListener("position_changed", panoChangeCallback);
      panoRef.current.addListener("pov_changed", panoChangeCallback);
    }
  }, [panoRef, panoChangeCallback]);

  return (
    <Container>
      <Pano ref={panoDivRef}/>
      <ResetButton onClick={() => panoRef.current.setPosition(resetPosition)}>
        Reset
      </ResetButton>
    </Container>
  );
};
